CircuitStat

Struct CircuitStat 

pub struct CircuitStat {
Show 16 fields pub n_gates: usize, pub n_eval_insn: usize, pub n_and_constraints: usize, pub n_mul_constraints: usize, pub distinct_shifted_value_indices: usize, pub distinct_unshifted_value_indices: usize, pub value_vec_len: usize, pub n_const: usize, pub n_inout: usize, pub n_witness: usize, pub n_internal: usize, pub n_scratch: usize, pub and_allocated: usize, pub mul_allocated: usize, pub public_allocated: usize, pub private_allocated: usize,
}
Various stats of a circuit that affect the prover performance.

Fields

n_gates: usize

Number of gates in the circuit.

n_eval_insn: usize

Number of instructions in the evaluation form of circuit.

Directly proportional to performance of witness filling.

n_and_constraints: usize

Number of AND constraints in the circuit.

Affects performance of AND reduction.

n_mul_constraints: usize

Number of MUL constraints in the circuit.

Affects performance of intmul reduction phase.

distinct_shifted_value_indices: usize

Number of distinct value indices with non-zero shift in the circuit.

Every use of a value with a distinct type and amount is counted here.

Affects performance of shift reduction phase.

distinct_unshifted_value_indices: usize

Number of distinct value indices with zero shift in the circuit.

Affects performance of shift reduction phase.

value_vec_len: usize

Length of the value vector.

Affects performance of committing.

n_const: usize

Number of constant values used by the circuit.

n_inout: usize

Number of public input values in the circuit.

n_witness: usize

Number of private input values in the circuit.

n_internal: usize

Number of internal values in the circuit.

Internal values are values produced by gates.

n_scratch: usize

Number of scratch values in the circuit.

Those values are not committed, those only exist during witness generation.

and_allocated: usize

Allocated size for AND constraints (power of 2)

mul_allocated: usize

Allocated size for MUL constraints (power of 2)

public_allocated: usize

Allocated size for public section (power of 2)

private_allocated: usize

Allocated size for private section.

This is the space available for witness and internal values. Note that unlike public_allocated and the total committed length, this is NOT necessarily a power of two. It’s simply the difference between the total committed length (power of 2) and the public section size (power of 2). For example, if total is 8192 and public is 128, private is 8064.

Implementations

Source

impl CircuitStat

pub fn collect(circuit: &Circuit) -> Self

Creates a new CircuitStat instance by collecting statistics from the given circuit.